@@ -38,6 +38,7 @@ class strain(sc.prettyobj):
     def __init__(self, strain, days, label=None, n_imports=1, rescale=True):
         self.days = days # Handle inputs
         self.n_imports = int(n_imports)
+        self.rescale   = rescale
         self.index     = None # Index of the strain in the sim; set later
         self.label     = None # Strain label (used as a dict key)
         self.p         = None # This is where the parameters will be stored
@@ -117,7 +118,8 @@ class strain(sc.prettyobj):
         ''' Introduce new infections with this strain '''
         for ind in cvi.find_day(self.days, sim.t, interv=self, sim=sim): # Time to introduce strain
             susceptible_inds = cvu.true(sim.people.susceptible)
-            n_imports = sc.randround(self.n_imports/sim.rescale_vec[sim.t]) # Round stochastically to the nearest number of imports
+            rescale_factor = sim.rescale_vec[sim.t] if self.rescale else 1.0
+            n_imports = sc.randround(self.n_imports/rescale_factor) # Round stochastically to the nearest number of imports
             importation_inds = np.random.choice(susceptible_inds, n_imports)
             sim.people.infect(inds=importation_inds, layer='importation', strain=self.index)
         return
@@ -251,29 +253,29 @@ def init_immunity(sim, create=False):
     # Pull out all of the circulating strains for cross-immunity
     ns       = sim['n_strains']
     immunity = {}
-    rel_imms = {}
-    strain_labels = sim['strain_map'].values()
-    for label in strain_labels:
-        rel_imms[label] = sim['strain_pars'][label]['rel_imm']
 
     # If immunity values have been provided, process them
     if sim['immunity'] is None or create:
-        # Initialize immunity
+
+        # Firstly, initialize immunity matrix with defaults. These are then overwitten with strain-specific values below
         for ax in cvd.immunity_axes:
             if ax == 'sus':  # Susceptibility matrix is of size sim['n_strains']*sim['n_strains']
-                immunity[ax] = np.full((ns, ns), sim['cross_immunity'], dtype=cvd.default_float)  # Default for off-diagnonals
-                np.fill_diagonal(immunity[ax], 1.0)  # Default for own-immunity
+                immunity[ax] = np.ones((ns, ns), dtype=cvd.default_float)  # Fill with defaults
             else:  # Progression and transmission are matrices of scalars of size sim['n_strains']
-                immunity[ax] = np.ones(ns, dtype=cvd.default_float)
+                immunity[ax] = np.ones(ns, dtype=cvd.default_float)  # Fill with defaults
 
+        # Next, overwrite these defaults with any known immunity values about specific strains
         default_cross_immunity = cvpar.get_cross_immunity()
         for i in range(ns):
+            label_i = sim['strain_map'][i]
             for j in range(ns):
-                if i != j:
-                    label_i = sim['strain_map'][i]
+                if i != j: # Populate cross-immunity
                     label_j = sim['strain_map'][j]
                     if label_i in default_cross_immunity and label_j in default_cross_immunity:
                         immunity['sus'][j][i] = default_cross_immunity[label_j][label_i]
+                else: # Populate own-immunity
+                    immunity['sus'][i, i] = sim['strain_pars'][label_i]['rel_imm_strain']
+
         sim['immunity'] = immunity
 
     # Next, precompute the NAb kinetics and store these for access during the sim
@@ -464,4 +466,4 @@ def linear_decay(length, init_val, slope):
 def linear_growth(length, slope):
     ''' Calculate linear growth '''
     t = np.arange(length, dtype=cvd.default_int)
-    return (slope * t)
\ No newline at end of file
+    return (slope * t)
