@@ -7,7 +7,7 @@ import covasim as cv
 from test_baselines import make_sim
 
 sim = make_sim(use_defaults=False, do_plot=False) # Use the same sim as from the regression/benchmarking tests
-to_profile = 'run' # Must be one of the options listed below
+to_profile = 'step' # Must be one of the options listed below
 
 func_options = {
     'make_contacts': cv.make_random_contacts,
